@@ -28,7 +28,6 @@
 smb_ioctlProc_t *smb_ioctlProcsp[SMB_IOCTL_MAXPROCS];
 
 /*extern unsigned char smb_LANadapter;*/
-extern LANA_ENUM lana_list;
 
 void smb_InitIoctl(void)
 {
@@ -69,9 +68,12 @@ void smb_InitIoctl(void)
 	smb_ioctlProcsp[VIOC_MAKESUBMOUNT] = cm_IoctlMakeSubmount;
 	smb_ioctlProcsp[VIOC_GETRXKCRYPT] = cm_IoctlGetRxkcrypt;
 	smb_ioctlProcsp[VIOC_SETRXKCRYPT] = cm_IoctlSetRxkcrypt;
+	smb_ioctlProcsp[VIOC_ISSYMLINK] = cm_IoctlIslink;
 #ifdef DJGPP
 	smb_ioctlProcsp[VIOC_SHUTDOWN] = cm_IoctlShutdown;
 #endif
+	smb_ioctlProcsp[VIOC_TRACEMEMDUMP] = cm_IoctlMemoryDump;
+	smb_ioctlProcsp[VIOC_ISSYMLINK] = cm_IoctlIslink;
 }
 
 /* called to make a fid structure into an IOCTL fid structure */
@@ -283,9 +285,14 @@ long smb_IoctlV3Read(smb_fid_t *fidp, smb_vc_t *vcp, smb_packet_t *inp, smb_pack
 		    osi_Log3(afsd_logp, "Ioctl uid %d user %x name %s",
 			     uidp->userID, userp,
 			     osi_LogSaveString(afsd_logp, uidp->unp->name));
-		else
+		else {
+			if (uidp)
 		    osi_Log2(afsd_logp, "Ioctl uid %d user %x no name",
 			     uidp->userID, userp);
+			else
+		    osi_Log1(afsd_logp, "Ioctl no uid user %x no name",
+			     userp);
+		}
 		smb_ReleaseUID(uidp);
 	}
 
