@@ -76,7 +76,11 @@
 #ifdef AFS_IA64_LINUX20_ENV
 #include "conf-ia64-linux.h"
 #else
+#ifdef AFS_AMD64_LINUX20_ENV
+#include "conf-amd64-linux.h"
+#else
 #include "conf-i386-linux.h"
+#endif /* AFS_AMD64_LINUX20_ENV */
 #endif /* AFS_IA64_LINUX20_ENV */
 #endif /* AFS_ALPHA_LINUX20_ENV */
 #endif /* AFS_S390_LINUX20_ENV */
@@ -88,8 +92,9 @@
 #if defined(AFS_DARWIN_ENV) && defined(AFS_PPC_ENV)
 #include "conf-ppc-darwin.h"
 #else
-Sorry, you lose.
-Figure out what the machine looks like and fix this file to include it.
+Sorry,
+    you lose.
+    Figure out what the machine looks like and fix this file to include it.
 #endif
 #endif /* AFS_LINUX20_ENV */
 #endif /* AFS_NT40_ENV */
@@ -98,9 +103,9 @@ Figure out what the machine looks like and fix this file to include it.
 #endif /* __alpha */
 #endif /* SGI */
 #endif /* NeXT */
-#endif	/* HP/UX */
+#endif /* HP/UX */
 #endif /* mac */
-#endif	/* aix */
+#endif /* aix */
 #endif /* sun */
 #endif /* mips */
 #endif /* not vax */
