@@ -12,7 +12,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/rx/rx_user.c,v 1.11.2.1 2002/09/10 22:33:55 zacheiss Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/rx/rx_user.c,v 1.14 2003/07/15 23:16:10 shadow Exp $");
 
 # include <sys/types.h>
 # include <errno.h>
@@ -92,13 +93,14 @@ pthread_mutex_t rx_if_mutex;
  * one.  Returns the socket (>= 0) on success.  Returns OSI_NULLSOCKET on
  * failure. Port must be in network byte order.	
  */
-osi_socket rxi_GetUDPSocket(u_short port)
+osi_socket
+rxi_GetUDPSocket(u_short port)
 {
-    int binds, code=0;
+    int binds, code = 0;
     osi_socket socketFd = OSI_NULLSOCKET;
     struct sockaddr_in taddr;
     char *name = "rxi_GetUDPSocket: ";
-    int greedy=0;
+    int greedy = 0;
 
 #if !defined(AFS_NT40_ENV) && !defined(AFS_DJGPP_ENV)
     if (ntohs(port) >= IPPORT_RESERVED && ntohs(port) < IPPORT_USERRESERVED) {
@@ -106,7 +108,9 @@ osi_socket rxi_GetUDPSocket(u_short port)
 */ ;
     }
     if (ntohs(port) > 0 && ntohs(port) < IPPORT_RESERVED && geteuid() != 0) {
-	(osi_Msg "%sport number %d is a reserved port number which may only be used by root.  Use port numbers above %d\n", name, ntohs(port), IPPORT_USERRESERVED);
+	(osi_Msg
+	 "%sport number %d is a reserved port number which may only be used by root.  Use port numbers above %d\n",
+	 name, ntohs(port), IPPORT_USERRESERVED);
 	goto error;
     }
 #endif
@@ -119,22 +123,23 @@ osi_socket rxi_GetUDPSocket(u_short port)
 
     taddr.sin_addr.s_addr = 0;
     taddr.sin_family = AF_INET;
-    taddr.sin_port = (u_short)port;
+    taddr.sin_port = (u_short) port;
 #ifdef STRUCT_SOCKADDR_HAS_SA_LEN
     taddr.sin_len = sizeof(struct sockaddr_in);
 #endif
 #define MAX_RX_BINDS 10
-    for (binds=0; binds<MAX_RX_BINDS; binds++) {
-      if (binds) rxi_Delay (10);
-      code = bind(socketFd, (struct sockaddr *) &taddr, sizeof(taddr));
-      if (!code) break;
+    for (binds = 0; binds < MAX_RX_BINDS; binds++) {
+	if (binds)
+	    rxi_Delay(10);
+	code = bind(socketFd, (struct sockaddr *)&taddr, sizeof(taddr));
+	if (!code)
+	    break;
     }
     if (code) {
-      perror("bind");
-      (osi_Msg "%sbind failed\n", name);
-      goto error;
+	perror("bind");
+	(osi_Msg "%sbind failed\n", name);
+	goto error;
     }
-
 #if !defined(AFS_NT40_ENV) && !defined(AFS_DJGPP_ENV)
     /*
      * Set close-on-exec on rx socket 
@@ -151,24 +156,29 @@ osi_socket rxi_GetUDPSocket(u_short port)
 	len1 = 32766;
 	len2 = rx_UdpBufSize;
 #ifndef AFS_DJGPP_ENV
-	greedy = 
-	  (setsockopt(socketFd, SOL_SOCKET, SO_RCVBUF, (char *)&len2,
-		      sizeof(len2)) >= 0);
-        if (!greedy) {
-	  len2=32766;  /* fall back to old size... uh-oh! */
+	greedy =
+	    (setsockopt
+	     (socketFd, SOL_SOCKET, SO_RCVBUF, (char *)&len2,
+	      sizeof(len2)) >= 0);
+	if (!greedy) {
+	    len2 = 32766;	/* fall back to old size... uh-oh! */
 	}
 
 	greedy =
-	  (setsockopt(socketFd, SOL_SOCKET, SO_SNDBUF, (char *)&len1,
-		      sizeof(len1)) >= 0) &&
-	  (setsockopt(socketFd, SOL_SOCKET, SO_RCVBUF, (char *)&len2,
-		      sizeof(len2)) >= 0);
+	    (setsockopt
+	     (socketFd, SOL_SOCKET, SO_SNDBUF, (char *)&len1,
+	      sizeof(len1)) >= 0)
+	    &&
+	    (setsockopt
+	     (socketFd, SOL_SOCKET, SO_RCVBUF, (char *)&len2,
+	      sizeof(len2)) >= 0);
 #endif /* AFS_DJGPP_ENV */
     }
 
 #ifndef AFS_DJGPP_ENV
     if (!greedy)
-	(osi_Msg "%s*WARNING* Unable to increase buffering on socket\n", name);
+	(osi_Msg "%s*WARNING* Unable to increase buffering on socket\n",
+	 name);
 #endif /* AFS_DJGPP_ENV */
     if (rxi_Listen(socketFd) < 0) {
 	goto error;
@@ -176,11 +186,13 @@ osi_socket rxi_GetUDPSocket(u_short port)
 
     return socketFd;
 
-error:
+  error:
 #ifdef AFS_NT40_ENV
-    if (socketFd >= 0) closesocket(socketFd);
+    if (socketFd >= 0)
+	closesocket(socketFd);
 #else
-    if (socketFd >= 0) close(socketFd);
+    if (socketFd >= 0)
+	close(socketFd);
 #endif
 
     MUTEX_ENTER(&rx_stats_mutex);
@@ -189,8 +201,8 @@ error:
     return OSI_NULLSOCKET;
 }
 
-void osi_Panic(msg, a1, a2, a3)
-    char *msg;
+void
+osi_Panic(char *msg, int a1, int a2, int a3)
 {
     (osi_Msg "Fatal Rx error: ");
     (osi_Msg msg, a1, a2, a3);
@@ -203,30 +215,33 @@ void osi_Panic(msg, a1, a2, a3)
  * osi_AssertFailU() -- used by the osi_Assert() macro.
  */
 
-void osi_AssertFailU(const char *expr, const char *file, int line)
+void
+osi_AssertFailU(const char *expr, const char *file, int line)
 {
-    osi_Panic("assertion failed: %s, file: %s, line: %d\n", expr, file, line);
+    osi_Panic("assertion failed: %s, file: %s, line: %d\n", (int)expr,
+	      (int)file, line);
 }
 
 #ifdef	AFS_AIX32_ENV
 #ifndef osi_Alloc
 static const char memZero;
-char * osi_Alloc(x)
-    afs_int32 x; 
+char *
+osi_Alloc(afs_int32 x)
 {
     /* 
      * 0-length allocs may return NULL ptr from osi_kalloc, so we special-case
      * things so that NULL returned iff an error occurred 
      */
-    if (x == 0) return &memZero;
-    return ((char *) malloc(x));
+    if (x == 0)
+	return &memZero;
+    return ((char *)malloc(x));
 }
 
-osi_Free(x, size)
-    char *x;
-    afs_int32 size; 
+void
+osi_Free(char *x, afs_int32 size)
 {
-    if (x == &memZero) return;
+    if (x == &memZero)
+	return;
     free((char *)x);
 }
 #endif
@@ -235,7 +250,7 @@ osi_Free(x, size)
 #define	ADDRSPERSITE	16
 
 
-afs_uint32 rxi_NetAddrs[ADDRSPERSITE]; /* host order */
+afs_uint32 rxi_NetAddrs[ADDRSPERSITE];	/* host order */
 static int myNetMTUs[ADDRSPERSITE];
 static int myNetMasks[ADDRSPERSITE];
 static int myNetFlags[ADDRSPERSITE];
@@ -243,7 +258,8 @@ u_int rxi_numNetAddrs;
 static int Inited = 0;
 
 #if defined(AFS_NT40_ENV) || defined(AFS_DJGPP_ENV)
-int rxi_getaddr(void)
+int
+rxi_getaddr(void)
 {
     if (rxi_numNetAddrs > 0)
 	return htonl(rxi_NetAddrs[0]);
@@ -256,10 +272,12 @@ int rxi_getaddr(void)
 ** and the addresses themselves in the buffer
 ** maxSize - max number of interfaces to return.
 */
-int rx_getAllAddr (afs_int32 *buffer, int maxSize)
+int
+rx_getAllAddr(afs_int32 * buffer, int maxSize)
 {
     int count = 0;
-    for (count = 0; count < rxi_numNetAddrs && maxSize > 0; count++, maxSize--)
+    for (count = 0; count < rxi_numNetAddrs && maxSize > 0;
+	 count++, maxSize--)
 	buffer[count] = htonl(rxi_NetAddrs[count]);
 
     return count;
@@ -269,95 +287,97 @@ int rx_getAllAddr (afs_int32 *buffer, int maxSize)
 
 #ifdef AFS_NT40_ENV
 
-void rx_GetIFInfo(void)
+void
+rx_GetIFInfo(void)
 {
-    LOCK_IF_INIT
-    if (Inited) {
-	UNLOCK_IF_INIT
-	return;
-    }
-    else {
+    LOCK_IF_INIT if (Inited) {
+	UNLOCK_IF_INIT return;
+    } else {
 	u_int maxsize;
 	u_int rxsize;
 	int npackets, ncbufs;
 	afs_uint32 i;
 
 	Inited = 1;
-	UNLOCK_IF_INIT
-	rxi_numNetAddrs = ADDRSPERSITE;
+	UNLOCK_IF_INIT rxi_numNetAddrs = ADDRSPERSITE;
 
-	LOCK_IF
-	(void) syscfg_GetIFInfo(&rxi_numNetAddrs, rxi_NetAddrs,
-				myNetMasks, myNetMTUs, myNetFlags);
+	LOCK_IF(void) syscfg_GetIFInfo(&rxi_numNetAddrs, rxi_NetAddrs,
+				       myNetMasks, myNetMTUs, myNetFlags);
 
-	for (i=0; i<rxi_numNetAddrs; i++) {
+	for (i = 0; i < rxi_numNetAddrs; i++) {
 	    rxsize = rxi_AdjustIfMTU(myNetMTUs[i] - RX_IPUDP_SIZE);
-	    maxsize = rxi_nRecvFrags*rxsize + (rxi_nRecvFrags-1)*UDP_HDR_SIZE;
+	    maxsize =
+		rxi_nRecvFrags * rxsize + (rxi_nRecvFrags - 1) * UDP_HDR_SIZE;
 	    maxsize = rxi_AdjustMaxMTU(rxsize, maxsize);
-	    if (rx_maxReceiveSize < maxsize)  {
-		rx_maxReceiveSize = MIN( RX_MAX_PACKET_SIZE, maxsize);
-		rx_maxReceiveSize = MIN( rx_maxReceiveSize,
-					 rx_maxReceiveSizeUser);
+	    if (rx_maxReceiveSize < maxsize) {
+		rx_maxReceiveSize = MIN(RX_MAX_PACKET_SIZE, maxsize);
+		rx_maxReceiveSize =
+		    MIN(rx_maxReceiveSize, rx_maxReceiveSizeUser);
 	    }
 
 	}
-	UNLOCK_IF
-	ncbufs = (rx_maxJumboRecvSize - RX_FIRSTBUFFERSIZE);
+	UNLOCK_IF ncbufs = (rx_maxJumboRecvSize - RX_FIRSTBUFFERSIZE);
 	if (ncbufs > 0) {
 	    ncbufs = ncbufs / RX_CBUFFERSIZE;
-	    npackets = rx_initSendWindow -1;
-	    rxi_MorePackets(npackets*(ncbufs+1));
+	    npackets = rx_initSendWindow - 1;
+	    rxi_MorePackets(npackets * (ncbufs + 1));
 	}
     }
 }
-    
+
 #endif
 
-static afs_uint32 fudge_netmask(addr) 
-afs_uint32 addr;
+static afs_uint32
+fudge_netmask(afs_uint32 addr)
 {
-afs_uint32 msk;
+    afs_uint32 msk;
 
-    if (IN_CLASSA(addr)) msk = IN_CLASSA_NET;
-    else if (IN_CLASSB(addr)) msk = IN_CLASSB_NET;
-    else if (IN_CLASSC(addr)) msk = IN_CLASSC_NET;
-    else msk = 0;
+    if (IN_CLASSA(addr))
+	msk = IN_CLASSA_NET;
+    else if (IN_CLASSB(addr))
+	msk = IN_CLASSB_NET;
+    else if (IN_CLASSC(addr))
+	msk = IN_CLASSC_NET;
+    else
+	msk = 0;
 
-return msk;
+    return msk;
 }
 
 
 
 #if !defined(AFS_AIX_ENV) && !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_DJGPP_ENV)
-int rxi_syscall(a3, a4, a5)
-afs_uint32 a3, a4;
-void * a5;
+int
+rxi_syscall(a3, a4, a5)
+     afs_uint32 a3, a4;
+     void *a5;
 {
-  afs_uint32 rcode;
-  void (*old)();
-	
-  old = (void (*)())signal(SIGSYS, SIG_IGN);	
+    afs_uint32 rcode;
+    void (*old) ();
+
+    old = (void (*)())signal(SIGSYS, SIG_IGN);
 
 #if defined(AFS_SGI_ENV)
-  rcode = afs_syscall(a3, a4, a5);
+    rcode = afs_syscall(a3, a4, a5);
 #else
-  rcode = syscall (AFS_SYSCALL, 28 /* AFSCALL_CALL */, a3, a4, a5);
+    rcode = syscall(AFS_SYSCALL, 28 /* AFSCALL_CALL */ , a3, a4, a5);
 #endif /* AFS_SGI_ENV */
 
-  signal(SIGSYS, old);	
+    signal(SIGSYS, old);
 
-return rcode;
+    return rcode;
 }
 #endif /* AFS_AIX_ENV */
 
 #ifndef AFS_NT40_ENV
-void rx_GetIFInfo()
+void
+rx_GetIFInfo(void)
 {
-    int     s;
-    int     i, j, len, res;
+    int s;
+    int i, j, len, res;
 #ifndef AFS_DJGPP_ENV
-    struct ifconf   ifc;
-    struct ifreq    ifs[ADDRSPERSITE];
+    struct ifconf ifc;
+    struct ifreq ifs[ADDRSPERSITE];
     struct ifreq *ifr;
 #ifdef	AFS_AIX41_ENV
     char buf[BUFSIZ], *cp, *cplim;
@@ -365,82 +385,77 @@ void rx_GetIFInfo()
     struct sockaddr_in *a;
 #endif /* AFS_DJGPP_ENV */
 
-    LOCK_IF_INIT
-    if (Inited) {
-      UNLOCK_IF_INIT
-      return;
+    LOCK_IF_INIT if (Inited) {
+	UNLOCK_IF_INIT return;
     }
     Inited = 1;
-    UNLOCK_IF_INIT
-
-    LOCK_IF
-    rxi_numNetAddrs = 0;
+    UNLOCK_IF_INIT LOCK_IF rxi_numNetAddrs = 0;
     memset(rxi_NetAddrs, 0, sizeof(rxi_NetAddrs));
     memset(myNetFlags, 0, sizeof(myNetFlags));
     memset(myNetMTUs, 0, sizeof(myNetMTUs));
     memset(myNetMasks, 0, sizeof(myNetMasks));
-    UNLOCK_IF
-
-    s = socket(AF_INET, SOCK_DGRAM, 0);
-    if (s < 0) return;
+    UNLOCK_IF s = socket(AF_INET, SOCK_DGRAM, 0);
+    if (s < 0)
+	return;
 
 #ifndef AFS_DJGPP_ENV
 #ifdef	AFS_AIX41_ENV
-    ifc.ifc_len = sizeof (buf);
+    ifc.ifc_len = sizeof(buf);
     ifc.ifc_buf = buf;
     ifr = ifc.ifc_req;
 #else
     ifc.ifc_len = sizeof(ifs);
-    ifc.ifc_buf = (caddr_t) &ifs[0];
+    ifc.ifc_buf = (caddr_t) & ifs[0];
     memset(&ifs[0], 0, sizeof(ifs));
-#endif 
+#endif
     res = ioctl(s, SIOCGIFCONF, &ifc);
     if (res < 0) {
-      /* fputs(stderr, "ioctl error IFCONF\n"); */
-      close(s);
-      return;
+	/* fputs(stderr, "ioctl error IFCONF\n"); */
+	close(s);
+	return;
     }
 
     LOCK_IF
-
 #ifdef	AFS_AIX41_ENV
 #define size(p) MAX((p).sa_len, sizeof(p))
-    cplim = buf + ifc.ifc_len; /*skip over if's with big ifr_addr's */
-    for (cp = buf; cp < cplim ;
+	cplim = buf + ifc.ifc_len;	/*skip over if's with big ifr_addr's */
+    for (cp = buf; cp < cplim;
 	 cp += sizeof(ifr->ifr_name) + MAX(a->sin_len, sizeof(*a))) {
 	if (rxi_numNetAddrs >= ADDRSPERSITE)
 	    break;
 
 	ifr = (struct ifreq *)cp;
 #else
-    len = ifc.ifc_len / sizeof(struct ifreq);
+	len = ifc.ifc_len / sizeof(struct ifreq);
     if (len > ADDRSPERSITE)
-      len = ADDRSPERSITE;
+	len = ADDRSPERSITE;
 
     for (i = 0; i < len; ++i) {
 	ifr = &ifs[i];
 	res = ioctl(s, SIOCGIFADDR, ifr);
 #endif
 	if (res < 0) {
-	  /* fputs(stderr, "ioctl error IFADDR\n");
-	    perror(ifr->ifr_name);   */
-	  continue;
+	    /* fputs(stderr, "ioctl error IFADDR\n");
+	     * perror(ifr->ifr_name);   */
+	    continue;
 	}
-	a = (struct sockaddr_in *) &ifr->ifr_addr;
-	if (a->sin_family != AF_INET) continue;
+	a = (struct sockaddr_in *)&ifr->ifr_addr;
+	if (a->sin_family != AF_INET)
+	    continue;
 	rxi_NetAddrs[rxi_numNetAddrs] = ntohl(a->sin_addr.s_addr);
 	if (rxi_NetAddrs[rxi_numNetAddrs] == 0x7f000001) {
-	  /* we don't really care about "localhost" */
-	  continue;
+	    /* we don't really care about "localhost" */
+	    continue;
 	}
- 	for (j=0; j < rxi_numNetAddrs; j++) {
-	   if (rxi_NetAddrs[j] == rxi_NetAddrs[rxi_numNetAddrs])
-	      break;
+	for (j = 0; j < rxi_numNetAddrs; j++) {
+	    if (rxi_NetAddrs[j] == rxi_NetAddrs[rxi_numNetAddrs])
+		break;
 	}
-	if (j < rxi_numNetAddrs) continue;
+	if (j < rxi_numNetAddrs)
+	    continue;
 
 	/* fprintf(stderr, "if %s addr=%x\n", ifr->ifr_name,
-		rxi_NetAddrs[rxi_numNetAddrs]); */
+	 * rxi_NetAddrs[rxi_numNetAddrs]); */
 
 #ifdef SIOCGIFFLAGS
 	res = ioctl(s, SIOCGIFFLAGS, ifr);
@@ -452,11 +467,10 @@ void rx_GetIFInfo()
 		continue;
 #endif
 	    /* fprintf(stderr, "if %s flags=%x\n", 
-		    ifr->ifr_name, ifr->ifr_flags); */
-	}
-	else { /*
-	  fputs(stderr, "ioctl error IFFLAGS\n");
-	  perror(ifr->ifr_name); */
+	     * ifr->ifr_name, ifr->ifr_flags); */
+	} else {		/*
+				 * fputs(stderr, "ioctl error IFFLAGS\n");
+				 * perror(ifr->ifr_name); */
 	}
 #endif /* SIOCGIFFLAGS */
 
@@ -470,86 +484,86 @@ void rx_GetIFInfo()
 	 * following code.  Fortunately, AIX is the one operating system in
 	 * which the subsequent ioctl works reliably. */
 	if (rxi_syscallp) {
-	  if ((*rxi_syscallp)( 20 /*AFSOP_GETMTU*/,  
-			      htonl(rxi_NetAddrs[rxi_numNetAddrs]),
-			      &(myNetMTUs[rxi_numNetAddrs]))) {
-	    /* fputs(stderr, "syscall error GETMTU\n");
-	       perror(ifr->ifr_name); */
-	    myNetMTUs[rxi_numNetAddrs] = 0;
-	  }
-	  if ((*rxi_syscallp)(42 /*AFSOP_GETMASK*/,  
-			      htonl(rxi_NetAddrs[rxi_numNetAddrs]),
-			      &(myNetMasks[rxi_numNetAddrs]))) {
-	    /* fputs(stderr, "syscall error GETMASK\n");
-	       perror(ifr->ifr_name); */
-	    myNetMasks[rxi_numNetAddrs] = 0;
-	  }
-	  else myNetMasks[rxi_numNetAddrs] = ntohl( myNetMasks[rxi_numNetAddrs]);
-	   /* fprintf(stderr, "if %s mask=0x%x\n", 
-	     ifr->ifr_name, myNetMasks[rxi_numNetAddrs]);*/
+	    if ((*rxi_syscallp) (20 /*AFSOP_GETMTU */ ,
+				 htonl(rxi_NetAddrs[rxi_numNetAddrs]),
+				 &(myNetMTUs[rxi_numNetAddrs]))) {
+		/* fputs(stderr, "syscall error GETMTU\n");
+		 * perror(ifr->ifr_name); */
+		myNetMTUs[rxi_numNetAddrs] = 0;
+	    }
+	    if ((*rxi_syscallp) (42 /*AFSOP_GETMASK */ ,
+				 htonl(rxi_NetAddrs[rxi_numNetAddrs]),
+				 &(myNetMasks[rxi_numNetAddrs]))) {
+		/* fputs(stderr, "syscall error GETMASK\n");
+		 * perror(ifr->ifr_name); */
+		myNetMasks[rxi_numNetAddrs] = 0;
+	    } else
+		myNetMasks[rxi_numNetAddrs] =
+		    ntohl(myNetMasks[rxi_numNetAddrs]);
+	    /* fprintf(stderr, "if %s mask=0x%x\n", 
+	     * ifr->ifr_name, myNetMasks[rxi_numNetAddrs]); */
 	}
 
 	if (myNetMTUs[rxi_numNetAddrs] == 0) {
-	  myNetMTUs[rxi_numNetAddrs] = OLD_MAX_PACKET_SIZE + RX_IPUDP_SIZE;
+	    myNetMTUs[rxi_numNetAddrs] = OLD_MAX_PACKET_SIZE + RX_IPUDP_SIZE;
 #ifdef SIOCGIFMTU
-	  res = ioctl(s, SIOCGIFMTU, ifr);
-	  if ((res == 0) && (ifr->ifr_metric > 128))  { /* sanity check */
-	    myNetMTUs[rxi_numNetAddrs] = ifr->ifr_metric;
-	    /* fprintf(stderr, "if %s mtu=%d\n", 
-		    ifr->ifr_name, ifr->ifr_metric); */
-	  }
-	  else {
-	    /* fputs(stderr, "ioctl error IFMTU\n");
-	       perror(ifr->ifr_name); */
-	  }
+	    res = ioctl(s, SIOCGIFMTU, ifr);
+	    if ((res == 0) && (ifr->ifr_metric > 128)) {	/* sanity check */
+		myNetMTUs[rxi_numNetAddrs] = ifr->ifr_metric;
+		/* fprintf(stderr, "if %s mtu=%d\n", 
+		 * ifr->ifr_name, ifr->ifr_metric); */
+	    } else {
+		/* fputs(stderr, "ioctl error IFMTU\n");
+		 * perror(ifr->ifr_name); */
+	    }
 #endif
 	}
 
 	if (myNetMasks[rxi_numNetAddrs] == 0) {
-	  myNetMasks[rxi_numNetAddrs] = fudge_netmask(rxi_NetAddrs[rxi_numNetAddrs]);
+	    myNetMasks[rxi_numNetAddrs] =
+		fudge_netmask(rxi_NetAddrs[rxi_numNetAddrs]);
 #ifdef SIOCGIFNETMASK
-	  res = ioctl(s, SIOCGIFNETMASK, ifr);
-	  if ((res == 0)) {
-	    a = (struct sockaddr_in *) &ifr->ifr_addr;
-	    myNetMasks[rxi_numNetAddrs] = ntohl(a->sin_addr.s_addr);
-	    /* fprintf(stderr, "if %s subnetmask=0x%x\n", 
-		    ifr->ifr_name, myNetMasks[rxi_numNetAddrs]); */
-	  }
-	  else {
-	    /* fputs(stderr, "ioctl error IFMASK\n");
-	       perror(ifr->ifr_name); */
-	  }
+	    res = ioctl(s, SIOCGIFNETMASK, ifr);
+	    if ((res == 0)) {
+		a = (struct sockaddr_in *)&ifr->ifr_addr;
+		myNetMasks[rxi_numNetAddrs] = ntohl(a->sin_addr.s_addr);
+		/* fprintf(stderr, "if %s subnetmask=0x%x\n", 
+		 * ifr->ifr_name, myNetMasks[rxi_numNetAddrs]); */
+	    } else {
+		/* fputs(stderr, "ioctl error IFMASK\n");
+		 * perror(ifr->ifr_name); */
+	    }
 #endif
 	}
 
-	if (rxi_NetAddrs[rxi_numNetAddrs] != 0x7f000001) { /* ignore lo0 */
-	   int maxsize;
-	   maxsize = rxi_nRecvFrags*(myNetMTUs[rxi_numNetAddrs] - RX_IP_SIZE);
-	   maxsize -= UDP_HDR_SIZE; /* only the first frag has a UDP hdr */
-	   if (rx_maxReceiveSize < maxsize) 
-		rx_maxReceiveSize = MIN( RX_MAX_PACKET_SIZE, maxsize);
-	   ++rxi_numNetAddrs;
+	if (rxi_NetAddrs[rxi_numNetAddrs] != 0x7f000001) {	/* ignore lo0 */
+	    int maxsize;
+	    maxsize =
+		rxi_nRecvFrags * (myNetMTUs[rxi_numNetAddrs] - RX_IP_SIZE);
+	    maxsize -= UDP_HDR_SIZE;	/* only the first frag has a UDP hdr */
+	    if (rx_maxReceiveSize < maxsize)
+		rx_maxReceiveSize = MIN(RX_MAX_PACKET_SIZE, maxsize);
+	    ++rxi_numNetAddrs;
 	}
     }
-    UNLOCK_IF
-    close(s);
+    UNLOCK_IF close(s);
 
     /* have to allocate at least enough to allow a single packet to reach its
      * maximum size, so ReadPacket will work.  Allocate enough for a couple
      * of packets to do so, for good measure */
     {
-      int npackets, ncbufs;
+	int npackets, ncbufs;
 
-      rx_maxJumboRecvSize = RX_HEADER_SIZE
-			    + rxi_nDgramPackets * RX_JUMBOBUFFERSIZE
-			    + (rxi_nDgramPackets-1) * RX_JUMBOHEADERSIZE;
-      rx_maxJumboRecvSize = MAX(rx_maxJumboRecvSize, rx_maxReceiveSize);
-      ncbufs = (rx_maxJumboRecvSize - RX_FIRSTBUFFERSIZE);
-      if (ncbufs > 0) {
-	ncbufs = ncbufs / RX_CBUFFERSIZE;
-	npackets = rx_initSendWindow -1;
-	rxi_MorePackets(npackets*(ncbufs+1));
-      }
+	rx_maxJumboRecvSize =
+	    RX_HEADER_SIZE + rxi_nDgramPackets * RX_JUMBOBUFFERSIZE +
+	    (rxi_nDgramPackets - 1) * RX_JUMBOHEADERSIZE;
+	rx_maxJumboRecvSize = MAX(rx_maxJumboRecvSize, rx_maxReceiveSize);
+	ncbufs = (rx_maxJumboRecvSize - RX_FIRSTBUFFERSIZE);
+	if (ncbufs > 0) {
+	    ncbufs = ncbufs / RX_CBUFFERSIZE;
+	    npackets = rx_initSendWindow - 1;
+	    rxi_MorePackets(npackets * (ncbufs + 1));
+	}
     }
 #else /* AFS_DJGPP_ENV */
     close(s);
@@ -565,7 +579,8 @@ void rx_GetIFInfo()
  * pthreads, this issue will need to be revisited.
  */
 
-void rxi_InitPeerParams(struct rx_peer *pp)
+void
+rxi_InitPeerParams(struct rx_peer *pp)
 {
     afs_uint32 ppaddr;
     u_short rxmtu;
@@ -573,17 +588,15 @@ void rxi_InitPeerParams(struct rx_peer *pp)
 
 
 
-    LOCK_IF_INIT
-    if (!Inited) {
+    LOCK_IF_INIT if (!Inited) {
 	UNLOCK_IF_INIT
-	/*
-	 * there's a race here since more than one thread could call
-	 * rx_GetIFInfo.  The race stops in rx_GetIFInfo.
-	 */
-	rx_GetIFInfo();
+	    /*
+	     * there's a race here since more than one thread could call
+	     * rx_GetIFInfo.  The race stops in rx_GetIFInfo.
+	     */
+	    rx_GetIFInfo();
     } else {
-	UNLOCK_IF_INIT
-    }
+    UNLOCK_IF_INIT}
 
 #ifdef ADAPT_MTU
     /* try to second-guess IP, and identify which link is most likely to
@@ -592,43 +605,42 @@ void rxi_InitPeerParams(struct rx_peer *pp)
 
     pp->ifMTU = 0;
     pp->timeout.sec = 2;
-    pp->rateFlag = 2;   /* start timing after two full packets */
+    pp->rateFlag = 2;		/* start timing after two full packets */
     /* I don't initialize these, because I presume they are bzero'd... 
      * pp->burstSize pp->burst pp->burstWait.sec pp->burstWait.usec
      * pp->timeout.usec */
-  
-    LOCK_IF
-    for (ix = 0; ix < rxi_numNetAddrs; ++ix) {
-      if ((rxi_NetAddrs[ix] & myNetMasks[ix]) == (ppaddr & myNetMasks[ix])) {
-#ifdef IFF_POINTOPOINT
-	if (myNetFlags[ix] & IFF_POINTOPOINT) 
-	   pp->timeout.sec = 4;
-#endif /* IFF_POINTOPOINT */
-	rxmtu = myNetMTUs[ix] - RX_IPUDP_SIZE;
-	if ( rxmtu < RX_MIN_PACKET_SIZE ) 
-	  rxmtu = RX_MIN_PACKET_SIZE ;
-	if (pp->ifMTU < rxmtu) 
-	  pp->ifMTU = MIN(rx_MyMaxSendSize, rxmtu);
-      }
-    }
-    UNLOCK_IF
 
-    if (!pp->ifMTU) { /* not local */
+    LOCK_IF for (ix = 0; ix < rxi_numNetAddrs; ++ix) {
+	if ((rxi_NetAddrs[ix] & myNetMasks[ix]) == (ppaddr & myNetMasks[ix])) {
+#ifdef IFF_POINTOPOINT
+	    if (myNetFlags[ix] & IFF_POINTOPOINT)
+		pp->timeout.sec = 4;
+#endif /* IFF_POINTOPOINT */
+	    rxmtu = myNetMTUs[ix] - RX_IPUDP_SIZE;
+	    if (rxmtu < RX_MIN_PACKET_SIZE)
+		rxmtu = RX_MIN_PACKET_SIZE;
+	    if (pp->ifMTU < rxmtu)
+		pp->ifMTU = MIN(rx_MyMaxSendSize, rxmtu);
+	}
+    }
+    UNLOCK_IF if (!pp->ifMTU) {	/* not local */
 	pp->timeout.sec = 3;
 	pp->ifMTU = RX_REMOTE_PACKET_SIZE;
     }
 #else /* ADAPT_MTU */
-    pp->rateFlag = 2;   /* start timing after two full packets */
+    pp->rateFlag = 2;		/* start timing after two full packets */
     pp->timeout.sec = 2;
     pp->ifMTU = OLD_MAX_PACKET_SIZE;
 #endif /* ADAPT_MTU */
     pp->ifMTU = rxi_AdjustIfMTU(pp->ifMTU);
-    pp->maxMTU = OLD_MAX_PACKET_SIZE;  /* for compatibility with old guys */
-    pp->natMTU = MIN((int)pp->ifMTU, OLD_MAX_PACKET_SIZE); 
-    pp->maxDgramPackets = MIN(rxi_nDgramPackets,
-			      rxi_AdjustDgramPackets(RX_MAX_FRAGS, pp->ifMTU));
-    pp->ifDgramPackets = MIN(rxi_nDgramPackets,
-			     rxi_AdjustDgramPackets(RX_MAX_FRAGS, pp->ifMTU));
+    pp->maxMTU = OLD_MAX_PACKET_SIZE;	/* for compatibility with old guys */
+    pp->natMTU = MIN((int)pp->ifMTU, OLD_MAX_PACKET_SIZE);
+    pp->maxDgramPackets =
+	MIN(rxi_nDgramPackets,
+	    rxi_AdjustDgramPackets(RX_MAX_FRAGS, pp->ifMTU));
+    pp->ifDgramPackets =
+	MIN(rxi_nDgramPackets,
+	    rxi_AdjustDgramPackets(RX_MAX_FRAGS, pp->ifMTU));
     pp->maxDgramPackets = 1;
     /* Initialize slow start parameters */
     pp->MTU = MIN(pp->natMTU, pp->maxMTU);
@@ -638,7 +650,8 @@ void rxi_InitPeerParams(struct rx_peer *pp)
 }
 
 /* Don't expose jumobgram internals. */
-void rx_SetNoJumbo(void)
+void
+rx_SetNoJumbo(void)
 {
     rx_maxReceiveSize = OLD_MAX_PACKET_SIZE;
     rxi_nSendFrags = rxi_nRecvFrags = 1;
